﻿# Picoscope 6 Release API
$releasesurlv2 = "https://updates.picotech.com/api/v2"

# Picoscipe 7 Releases API
$releasesurlv3 = "https://updates-api.picotech.com/api/v3/Releases"

# Location of the Pico Driver Signing Certificate
$picodrivercert = $(Split-Path -Parent $PSCommandPath) + "\Pico_Technology_Ltd.cer"

# Location of the Pico Driver EV Signing Certificate
$picodriverevcert = $(Split-Path -Parent $PSCommandPath) + "\Pico_Technology_Ltd_EV.cer"

write-host "Installing Pico Technology Ltd driver certificate"
Import-Certificate -FilePath $picodrivercert -CertStoreLocation Cert:\LocalMachine\TrustedPublisher
Import-Certificate -FilePath $picodriverevcert -CertStoreLocation Cert:\LocalMachine\TrustedPublisher

# Enable TLS 1.2
$TLS12Protocol = [System.Net.SecurityProtocolType] 'Ssl3 , Tls12'
[System.Net.ServicePointManager]::SecurityProtocol = $TLS12Protocol

# Make Picoscope 6 API calls
write-host "Get Picoscope 6 versions"
$retjsonv2 = Invoke-WebRequest -uri $releasesurlv2 | Convertfrom-json

write-host "Downloading the latest PicoScope 6 TNM"
$picoscope6url = $retjsonv2 | where-object {($_.name -eq "PicoScope" -and $_.Oem -eq "TandM" -and $_.Beta -eq $false)} | Sort-Object {[version] $_.version} | select-object -Last 1 | Select -ExpandProperty "url"
Invoke-WebRequest -uri $picoscope6url -outfile "$env:TEMP\picoscope6tnm-install.exe"

write-host "Installing latest PicoScope 6"
Start-Process -Wait -FilePath "$env:TEMP\picoscope6tnm-install.exe" -ArgumentList '/s /v"INSTALL_ALL_CONVERTERS="Yes" /qn'

# Make Picoscope 7 API calls
write-host "Get Picoscope 7 versions"
$retjsonv3 = Invoke-WebRequest -uri $releasesurlv3 | Convertfrom-json

write-host "Downloading the latest PicoScope 7 TNM Early Access"
$picoscope7tnmurl = $retjsonv3 | where-object {($_.name -eq "PicoScope" -and $_.url -like "https://oem.picotech.com*exe")} | Sort-Object {[version] $_.version} | select-object -Last 1 | Select -ExpandProperty "url"
Invoke-WebRequest -uri $picoscope7tnmurl -outfile "$env:TEMP\picoscope7tnm-install.exe"

write-host "Installing latest PicoScope 7 TNM Early Access"
Start-Process -Wait -FilePath "$env:TEMP\picoscope7tnm-install.exe" -ArgumentList '/s /v"INSTALL_ALL_CONVERTERS="Yes" /qn'

write-host "Downloading the latest PicoScope 7 Auto"
$picoscope7autourl = $retjsonv3 | where-object {($_.name -eq "PicoScope" -and $_.url -like "https://www.picoauto.com*exe"  -and  $_.isBetaVersion -eq $false)} | Sort-Object {[version] $_.version} | select-object -Last 1 | Select -ExpandProperty "url"
Invoke-WebRequest -uri $picoscope7autourl -outfile "$env:TEMP\picoscope7auto-install.exe"

write-host "Installing latest PicoScope 7 Auto"
Start-Process -Wait -FilePath "$env:TEMP\picoscope7auto-install.exe" -ArgumentList '/s /v"INSTALL_ALL_CONVERTERS="Yes" /qn'

write-host "Downloading the latest PicoLog 6"
$picolog6url = $retjsonv3 | where-object {($_.name -eq "PicoLog" -and $_.url -like "https://www.picotech.com*exe")} | Sort-Object {[version] $_.version} | select-object -Last 1 | Select -ExpandProperty "url"
Invoke-WebRequest -uri $picolog6url -outfile "$env:TEMP\picolog6-install.exe"

write-host "Installing latest PicoLog 6"
Start-Process -Wait -FilePath "$env:TEMP\picolog6-install.exe" -ArgumentList '/S'